@@ -1116,18 +1116,6 @@ def getMdRaidDevices():
                     reSearch(reMdInfo, readLinesFile('/proc/mdstat'))))
 
 
-def sambaPasswordCheck(username, password, server, resource):
-    """
-    Подключиться к указанному samba ресурсу сервера по логину паролю
-    """
-    smbclient = getProgPath('/usr/sbin/smbclient')
-    if not smbclient:
-        raise FilesError(_("Command not found '%s'") % "smbclint")
-    p = process(smbclient, "-U", username, "//%s/%s" % (server, resource),
-                envdict={'PASSWD': password})
-    return p.success()
-
-
 class PercentProgress(processProgress):
     """
     Объект выдает прогресс, ища в выводе \d+%
